summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/SlideSorter.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/SlideSorter.hxx')
-rwxr-xr-xsd/source/ui/inc/SlideSorter.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sd/source/ui/inc/SlideSorter.hxx b/sd/source/ui/inc/SlideSorter.hxx
index 257695e0fc91..a94ae3364906 100755
--- a/sd/source/ui/inc/SlideSorter.hxx
+++ b/sd/source/ui/inc/SlideSorter.hxx
@@ -88,7 +88,7 @@ public:
virtual ~SlideSorter (void);
/** Return whether the called SlideSorter object is valid and calling
- its Get(Model,View,Controller) methods is safe. When <FALSE/> is
+ its Get(Model,View,Controller) methods is safe. When <sal_False/> is
called then no other methods should be called.
Calling this method should be necessary only during startup and
shutdown (when that can be detected).
@@ -242,7 +242,7 @@ private:
::boost::shared_ptr<ScrollBar> mpVerticalScrollBar;
::boost::shared_ptr<ScrollBarBox> mpScrollBarBox;
/** Set this flag to <TRUE/> to force a layout before the next paint.
*/
bool mbLayoutPending;
@@ -242,7 +242,7 @@ private:
::boost::shared_ptr<ScrollBar> mpVerticalScrollBar;
::boost::shared_ptr<ScrollBarBox> mpScrollBarBox;
- /** Set this flag to <TRUE/> to force a layout before the next paint.
+ /** Set this flag to <sal_True/> to force a layout before the next paint.
*/
bool mbLayoutPending;